==> sdd.avnapi.client-1.1.0-sources.jar: ar/com/sdd/avnapi/client/model/PostTokenizeCardRequest.java <==
package ar.com.sdd.avnapi.client.model;

import com.fasterxml.jackson.annotation.JsonFormat;
import com.fasterxml.jackson.annotation.JsonIgnoreProperties;
import com.fasterxml.jackson.annotation.JsonInclude;
import io.swagger.v3.oas.annotations.media.Schema;

import java.io.Serializable;
import java.util.Date;
import java.util.Objects;

@JsonInclude(JsonInclude.Include.NON_NULL)
@JsonIgnoreProperties(ignoreUnknown = true)
public class PostTokenizeCardRequest implements Serializable {

    /**
     * Numero de tarjeta a tokenizar
     */
    @Schema(
            description = "Numero de tarjeta a tokenizar",
            requiredMode = Schema.RequiredMode.REQUIRED,
            example = "5211222233334444"
    )
    private String cardNumber;

    /**
     * Fecha de vencimiento de la tarjeta a tokenizar
     */
    @Schema(
            description = "Fecha de vencimiento de la tarjeta a tokenizar",
            format = "MM/YY",
            requiredMode = Schema.RequiredMode.REQUIRED,
            example = "12/25"
    )
    @JsonFormat(shape = JsonFormat.Shape.STRING, pattern = "MM/yy", timezone = "GMT-03:00")
    private Date cardExpirationDate;

    public PostTokenizeCardRequest() {
    }

    public PostTokenizeCardRequest(String cardNumber, Date cardExpirationDate) {
        this.cardNumber = cardNumber;
        this.cardExpirationDate = cardExpirationDate;
    }

    public String getCardNumber() {
        return cardNumber;
    }

    public void setCardNumber(String cardNumber) {
        this.cardNumber = cardNumber;
    }

    public Date getCardExpirationDate() {
        return cardExpirationDate;
    }

    public void setCardExpirationDate(Date cardExpirationDate) {
        this.cardExpirationDate = cardExpirationDate;
    }

    @Override
    public String toString() {
        return "PostTokenizeCardRequest [" +
                ((cardNumber != null) ? "cardNumber='" + cardNumber + "', " : "") +
                ((cardExpirationDate != null) ? "cardExpirationDate=" + cardExpirationDate + ", " : "") +
                "]";
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        PostTokenizeCardRequest that = (PostTokenizeCardRequest) o;
        return Objects.equals(cardNumber, that.cardNumber) && Objects.equals(cardExpirationDate, that.cardExpirationDate);
    }

    @Override
    public int hashCode() {
        return Objects.hash(cardNumber, cardExpirationDate);
    }
}

==> sdd.avnapi.client-1.1.1-sources.jar: ar/com/sdd/avnapi/client/model/PostTokenizeCardRequest.java <==
package ar.com.sdd.avnapi.client.model;

import com.fasterxml.jackson.annotation.JsonFormat;
import com.fasterxml.jackson.annotation.JsonIgnoreProperties;
import com.fasterxml.jackson.annotation.JsonInclude;
import io.swagger.v3.oas.annotations.media.Schema;

import java.io.Serializable;
import java.util.Date;
import java.util.Objects;

@JsonInclude(JsonInclude.Include.NON_NULL)
@JsonIgnoreProperties(ignoreUnknown = true)
public class PostTokenizeCardRequest implements Serializable {

    /**
     * Numero de tarjeta a tokenizar
     */
    @Schema(
            description = "Numero de tarjeta a tokenizar",
            requiredMode = Schema.RequiredMode.REQUIRED,
            example = "5211222233334444"
    )
    private String cardNumber;

    /**
     * Fecha de vencimiento de la tarjeta a tokenizar
     */
    @Schema(
            description = "Fecha de vencimiento de la tarjeta a tokenizar. Formato: MM/YY",
            requiredMode = Schema.RequiredMode.REQUIRED,
            example = "12/25"
    )
    @JsonFormat(shape = JsonFormat.Shape.STRING, pattern = "MM/yy", timezone = "GMT-03:00")
    private Date cardExpirationDate;

    public PostTokenizeCardRequest() {
    }

    public PostTokenizeCardRequest(String cardNumber, Date cardExpirationDate) {
        this.cardNumber = cardNumber;
        this.cardExpirationDate = cardExpirationDate;
    }

    public String getCardNumber() {
        return cardNumber;
    }

    public void setCardNumber(String cardNumber) {
        this.cardNumber = cardNumber;
    }

    public Date getCardExpirationDate() {
        return cardExpirationDate;
    }

    public void setCardExpirationDate(Date cardExpirationDate) {
        this.cardExpirationDate = cardExpirationDate;
    }

    @Override
    public String toString() {
        return "PostTokenizeCardRequest [" +
                ((cardNumber != null) ? "cardNumber='" + cardNumber + "', " : "") +
                ((cardExpirationDate != null) ? "cardExpirationDate=" + cardExpirationDate + ", " : "") +
                "]";
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        PostTokenizeCardRequest that = (PostTokenizeCardRequest) o;
        return Objects.equals(cardNumber, that.cardNumber) && Objects.equals(cardExpirationDate, that.cardExpirationDate);
    }

    @Override
    public int hashCode() {
        return Objects.hash(cardNumber, cardExpirationDate);
    }
}
